# SPDX-License-Identifier: MIT


# Import local modules.
from .main import *

# Set version information.
__version_info__ = ('2024', '2', '17')  # YYYY / MM / DD
__version__ = '.'.join(__version_info__)



# SPDX-License-Identifier: MIT


# Import first-party Python modules.
import os
import sys
from typing import NoReturn

# Add support layer for accessing the primary package.
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))

# Import local modules.
from avro.utils import validate

# Set up test environments.
vowels = 'aeiou'
consonants = 'bcdfghjklmnpqrstvwxyz'
numbers = '0123456789'
prekars = ['ি', 'ৈ', 'ে']
banjonborno = 'কখগঘঙচছজঝঞটঠডঢণতথদধনপফবভমশষসহযরলয়ংঃঁৎ'


# Test functions for this file.
def test_is_consonant() -> NoReturn:
    """
    Test that consonants are correctly identified.
    """

    for i in consonants + consonants.upper():
        assert validate.is_consonant(i)

    for i in vowels + numbers:
        assert not validate.is_consonant(i)


def test_is_number() -> NoReturn:
    """
    Test that numbers are correctly identified.
    """

    for i in numbers:
        assert validate.is_number(i)

    for i in vowels + consonants:
        assert not validate.is_number(i)


def test_is_vowel() -> NoReturn:
    """
    Test that vowels are correctly identified.
    """

    for i in vowels + vowels.upper():
        assert validate.is_vowel(i)

    for i in consonants + numbers:
        assert not validate.is_vowel(i)


def test_is_punctuation() -> NoReturn:
    """
    Test that punctuations are correctly identified.

    Anything that is neither a number, nor vowel nor consonant is
    identified as a punctuation.
    """

    for i in '`~!@#$%^&*()-_=+\\|[{}]\'",<.>/?':
        assert validate.is_punctuation(i)
        assert not validate.is_vowel(i)
        assert not validate.is_consonant(i)
        assert not validate.is_number(i)


def test_fix_string_case() -> NoReturn:
    """
    Test phonetic-compatible case-transformations of strings.

    This ensures validate.fix_strings function works as
    expected. It should properly change text to lowercase but
    retain case-sensitive characters defined in config as
    uppercase.
    """

    assert validate.fix_string_case('ABOL taBOl') == 'abOl tabOl'
    assert validate.fix_string_case('KhiCuRi') == 'khicuRi'
    assert validate.fix_string_case('KaTh-BuRO') == 'kaTh-buRO'
    assert validate.fix_string_case('raMgoRurer Chana') == 'ramgoRurer chana'


def test_is_exact() -> NoReturn:
    """
    Test exact search response of needle in haystack.
    """

    assert validate.is_exact('abcd', 'abcdefgh', 0, 4, False)
    assert not validate.is_exact('abcd', 'abcdefgh', 0, 4, True)
    assert not validate.is_exact('bcd', 'abcdefgh', 0, 4, False)
    assert validate.is_exact('bcd', 'abcdefgh', 0, 4, True)

    assert not validate.is_exact('a', 'a', 1, 2, False)
    assert validate.is_exact('a', 'a', 1, 2, True)


def test_is_prekar() -> NoReturn:
    """
    Test if given string is a prekar.
    """

    for i in prekars:
        assert validate.is_bangla_prekar(i)

    assert not (
        validate.is_bangla_prekar('া')
        and validate.is_bangla_prekar('ূ')
        and validate.is_bangla_prekar('a')
        and validate.is_bangla_prekar('b')
    )


def test_is_banjonborno() -> NoReturn:
    """
    Test if given string is a banjonborno.
    """

    for i in banjonborno:
        assert validate.is_bangla_banjonborno(i)

    assert not (
        validate.is_bangla_banjonborno('a')
        and validate.is_bangla_banjonborno('ূ')
        and validate.is_bangla_banjonborno('া')
        and validate.is_bangla_banjonborno('b')
    )


def test_is_halant() -> NoReturn:
    """
    Test if given string is a halant.
    """

    assert validate.is_bangla_halant('্')
    assert not (
        validate.is_bangla_halant('a')
        and validate.is_bangla_halant('ূ')
        and validate.is_bangla_halant('া')
        and validate.is_bangla_halant('b')
    )



# SPDX-License-Identifier: MIT


# Import first-party Python modules.
import os
import sys
from typing import NoReturn

# Add support layer for accessing the primary package.
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))

# Import local modules.
from avro.utils import count


# Test functions for this file.
def test_count_vowels() -> NoReturn:
    """
    Test vowel count in a given string.
    """

    strings = {
        'haTTima Tim Tim': 5,
        'tara maThe paRe Dim': 7,
        'tader mathay duTO sing': 7,
        'tara haTTima Tim Tim': 7,
    }

    for string, integer in strings.items():
        assert count.count_vowels(string) == integer


def test_count_consonants() -> NoReturn:
    """
    Test consonant count in a given string.
    """

    strings = {
        'ei dekh pensil': 7,
        'nOTbuk e hate': 6,
        'ei dekh bhora sob': 8,
        'kil`bil lekha te': 8,
    }

    for string, integer in strings.items():
        assert count.count_consonants(string) == integer



# SPDX-License-Identifier: MIT


# Import local modules.
from avro import config


# Functions.
def count_vowels(text: str) -> int:
    """
    Count number of occurrences of vowels in a given string.
    """

    count = 0

    for i in text:
        if i.lower() in config.AVRO_VOWELS:
            count += 1

    return count


def count_consonants(text: str) -> int:
    """
    Count number of occurrences of consonants in a given string.
    """

    count = 0

    for i in text:
        if i.lower() in config.AVRO_CONSONANTS:
            count += 1

    return count



# SPDX-License-Identifier: MIT


# Import local modules.
from .resources import DICT

# Shortcuts to vowels, constants, case-sensitives and numbers.
AVRO_VOWELS = set(DICT['avro']['vowel'])
AVRO_CONSONANTS = set(DICT['avro']['consonant'])
AVRO_CASESENSITIVES = set(DICT['avro']['casesensitive'])
AVRO_NUMBERS = set(DICT['avro']['number'])

# Shortcuts to Bengali Svaravarna, Kar(s)
AVRO_SHORBORNO = set(DICT['avro']['shorborno'])
AVRO_KAR = DICT['avro']['kar']
AVRO_IGNORE = DICT['avro']['ignore']
AVRO_EXCEPTIONS = DICT['avro']['exceptions']

# Shortcuts for conversion (e.g. for Bijoy Keyboard support).
BIJOY_MAP = DICT['bijoy']['mappings']
BIJOY_PREKAR = DICT['bijoy']['prekar']
BIJOY_BANJONBORNO = DICT['bijoy']['banjonborno']
BIJOY_EXCEPTIONS = DICT['bijoy']['exceptions']
